@@ -29,6 +29,8 @@
 #' @noRd
 .getColAndSize <- function(data, coords, mergeBy, mcy, t, colVar, sizeVar, 
                            popupVars, colorScaleOpts, labelVar = NULL) {
+
+  
   
   if (mcy != "average") data <- data[J(as.numeric(mcy))]
   
@@ -56,17 +58,30 @@
   res <- list(coords = data, dir = 0)
   
   # color
+  
   if (!colVar %in% names(data)) colVar <- "none"
   if (colVar != "none") {
     if (is.numeric(data[[colVar]])) {
       rangevar <- range(data[[colVar]])
+      if(length(colorScaleOpts$breaks) > 1 ){
+        if(min(rangevar) < min(colorScaleOpts$breaks)){
+          colorScaleOpts$breaks <- c(min(rangevar), colorScaleOpts$breaks)
+          colorScaleOpts$colors <- c("noColor", colorScaleOpts$colors)
+        }
+        
+        if(max(rangevar) > max(colorScaleOpts$breaks)){
+          colorScaleOpts$breaks <- c( colorScaleOpts$breaks, max(rangevar))
+          colorScaleOpts$colors <- c( colorScaleOpts$colors, "noColor")
+        }
+      }
+      
       # Special case of FLOW LIN
       if (colVar == "FLOW LIN.") rangevar <- c(0, max(abs(rangevar)))
       
       if (rangevar[1] >= 0) {
         domain <- rangevar
       } else {
-        domain <- c(-max(abs(rangevar)), max(abs(rangevar)))
+        domain <- c(-min(rangevar), max(rangevar))
       }
       
       if (colVar == "FLOW LIN.") colorScaleOpts$x <- abs(data[[colVar]])
@@ -119,7 +134,7 @@
     timeStep,
     hourly = "%a %d %b %Y<br/>%H:%M",
     daily = "%a %d %b %Y",
-    weekly = "W%w %Y",
+    weekly = "W%V %Y",
     monthly = "%b %Y",
     yearly = "%Y"
   )
@@ -145,9 +160,11 @@
 .redrawCircles <- function(map, x, mapLayout, mcy, t, colAreaVar, sizeAreaVars,
                            popupAreaVars, uniqueScale, showLabels, labelAreaVar,
                            areaChartType,
-                           options) {
+                           options, sizeMiniPlot = FALSE) {
   
   if (is.null(x$areas)) return(map)
+  if (nrow(x$areas) == 0) return(map)
+  
   timeStep <- attr(x, "timeStep")
   
   # Just in case, we do not want to accidentally modify the original map layout.
@@ -159,6 +176,7 @@
                              options$areaColorScaleOpts, labelVar = labelAreaVar)
   ml$coords <- optsArea$coords
   
+  
   # Use default values if needed.
   if (is.null(optsArea$color)) optsArea$color <- options$areaDefaultCol
   
@@ -213,10 +231,41 @@
     }
   }
   
+  if(sizeMiniPlot)
+  {
+    if(is.matrix(optsArea$size))
+    {
+      if(ncol(optsArea$size) > 1 )
+      {
+        optsArea$Va <- rowSums(optsArea$size)
+        optsArea$VaP <- optsArea$Va / max(optsArea$Va)
+        fM <- 3
+        optsArea$Ra <- 15 + (optsArea$VaP * fM * 30)/2
+      }
+    }
+  }
+  
+  if(is.null(optsArea$Ra)){optsArea$Ra <- width}
   # Update areas
+  
+  #Apply colors defined in color.csv
+  if(is.null(options$areaChartColors))
+  {
+  varS <- names(optsArea$maxSize)
+  colorDef <- colorsVars$colors[match(varS, colorsVars$Column)]
+  defCol <- c("#1f77b4", "#ff7f0e", "#2ca02c", "#d62728", "#9467bd", "#8c564b",
+              "e377c2",  "#7f7f7f", "#bcbd22", "#17becf")
+  nbNa <- sum(is.na(colorDef))
+  if(nbNa > 0)
+  {
+  colorDef[is.na(colorDef)] <- defCol[1:nbNa]
+  }
+  options$areaChartColors <- colorDef
+  }
+  
   map <- updateMinicharts(map, optsArea$coords$area, chartdata = optsArea$size,
                           time = optsArea$coords$time,
-                          maxValues = optsArea$maxSize, width = width,
+                          maxValues = optsArea$maxSize, width = optsArea$Ra,
                           height = options$areaMaxHeight,
                           showLabels = showLabels, labelText = labels, 
                           type = areaChartType[[1]], 
@@ -265,6 +314,7 @@
 .redrawLinks <- function(map, x, mapLayout, mcy, t, colLinkVar, sizeLinkVar, 
                          popupLinkVars, options) {
   if (is.null(x$links)) return(map)
+  if (nrow(x$links) == 0) return(map)
   
   timeStep <- attr(x, "timeStep")
   
@@ -276,7 +326,7 @@
                              options$linkColorScaleOpts)
   
   # Use default values if needed
-  if (is.null(optsLink$color)) optsLink$color <- options$linkDefaultCol
+  if (is.null(optsLink$color) | options$linkDefaultCol != "#BEBECE") optsLink$color <- options$linkDefaultCol
   if (is.null(optsLink$size)) {
     optsLink$size <- options$linkDefaultSize
     optsLink$maxSize <- options$linkMaxSize
@@ -297,7 +347,7 @@
                                labels = sizeLinkVar,
                                digits = 2,
                                supValues = optsLink$coords[, optsLink$popupVars, with = FALSE]
-                              ),
+                             ),
                              opacity = 1)
   
   # Update the legend
