@@ -9,10 +9,9 @@
 #' @param x
 #'   An object of class \code{antaresData} created with function 
 #'   \code{\link[antaresRead]{readAntares}} containing data for areas and or
-#'   districts.
-#' @param y
-#'   Optional object of class \code{antaresData}. If it is specified, then two
-#'   charts are generated.
+#'   districts. it can be a list of \code{antaresData} objects. 
+#'   In this case, one chart is created for each object. 
+#'   Can also contains opts who refer to a h5 file or list of opts.
 #' @param stack
 #'   Name of the stack to use. One can visualize available stacks with 
 #'   \code{prodStackAliases}
@@ -35,7 +34,8 @@
 #'   An optional character vector containing names of parameters. When it is set,
 #'   two charts are outputed with their own input controls. Alternatively, it can
 #'   be a named list with names corresponding to parameter names and values being
-#'   list with the initial values of the given parameter for each chart.
+#'   list with the initial values of the given parameter for each chart. See details
+#'    if you are drawing a map.
 #' @param compareOpts
 #'   List of options that indicates the number of charts to create and their 
 #'   position. Check out the documentation of 
@@ -84,9 +84,21 @@
 #' @param description
 #'   Description of the stack. It is displayed by function 
 #'   \code{prodStackAliases}.
+#' @param xyCompare
+#'   Use when you compare studies, can be "union" or "intersect". If union, all
+#'   of mcYears in one of studies will be selectable. If intersect, only mcYears in all
+#'   studies will be selectable.
+#' @param h5requestFiltering Contains arguments used by default for h5 request,
+#'   typically h5requestFiltering = list(select = "NUCLEAR")
+#' @param stepPlot \code{boolean}, step style for curves.
+#' @param drawPoints \code{boolean}, add points on graph
+#' @param timeSteph5 \code{character} timeStep to read in h5 file. Only for Non interactive mode.
+#' @param mcYearh5 \code{numeric} mcYear to read for h5. Only for Non interactive mode.
+#' @param tablesh5 \code{character} tables for h5 ("areas" "links", "clusters" or "disticts"). Only for Non interactive mode.
+#' @param ... Other arguments for \code{\link{manipulateWidget}}
 #'  
 #' @return 
-#' \code{prodStackAliases} returns an interactive html graphic. If argument
+#' \code{prodStack} returns an interactive html graphic. If argument
 #' \code{interactive} is \code{TRUE}, then a shiny gadget is started and the
 #' function returns an interactive html graphic when the user clicks on button
 #' "Done".
@@ -97,15 +109,27 @@
 #' 
 #' @seealso \code{\link{prodStackLegend}}
 #' 
+#' @details 
+#' compare argument can take following values :
+#' \itemize{
+#'    \item "mcYear"
+#'    \item "main"
+#'    \item "unit"
+#'    \item "areas"
+#'    \item "legend"
+#'    \item "stack"
+#'    \item "stepPlot"
+#'    \item "drawPoints"
+#'    }
 #' @examples
 #' \dontrun{
 #' mydata <- readAntares(areas = "all", timeStep = "daily")
 #' 
 #' # Start a shiny gadget that permits to choose areas to display.
-#' prodStack(mydata, unit = "GWh")
+#' prodStack(x = mydata, unit = "GWh")
 #' 
 #' # Use in a non-interactive way
-#' prodStack(mydata, unit = "GWh", areas = "fr", interactive = FALSE)
+#' prodStack(x = mydata, unit = "GWh", areas = "fr", interactive = FALSE)
 #' 
 #' # Define a custom stack
 #' setProdStackAlias(
@@ -114,7 +138,7 @@
 #'   colors = c("green", "orange")
 #' )
 #' 
-#' prodStack(mydata, unit = "GWh", stack = "Wind and solar")
+#' prodStack(x = mydata, unit = "GWh", stack = "Wind and solar")
 #'                 
 #' # In a custom stack it is possible to use computed values
 #' setProdStackAlias(
@@ -128,12 +152,46 @@
 #'   lineColors = "#42EB09"
 #' )
 #' 
-#' prodStack(mydata, unit = "GWh", stack = "renewable")
+#' prodStack(x = mydata, unit = "GWh", stack = "renewable")
+#' 
+#' # Use compare
+#' prodStack(x = mydata, compare = "areas")
+#' prodStack(x = mydata, unit = "GWh", compare = "mcYear")
+#' prodStack(x = mydata, unit = "GWh", compare = "main")
+#' prodStack(x = mydata, unit = "GWh", compare = "unit")
+#' prodStack(x = mydata, unit = "GWh", compare = "areas")
+#' prodStack(x = mydata, unit = "GWh", compare = "legend")
+#' prodStack(x = mydata, unit = "GWh", compare = "stack")
+#' prodStack(x = mydata, unit = "GWh", compare = c("mcYear", "areas"))
+#' 
+#' 
+#' # Compare studies
+#' prodStack(list(mydata, mydata))
+#' 
+#' 
+#' # Use h5 opts
+#' # Set path of simulaiton
+#' setSimulationPath(path = path1)
+#' 
+#' # Convert your study in h5 format
+#' writeAntaresH5(path = mynewpath)
+#' 
+#' # Redefine sim path with h5 file
+#' opts <- setSimulationPath(path = mynewpath)
+#' prodStack(x = opts)
+#' 
+#' # Compare elements in a single study
+#' prodStack(x = opts, .compare = "mcYear")
+#' 
+#' # Compare 2 studies
+#' prodStack(x = list(opts, opts2))
+#' 
+#' 
 #'                 
 #' }
 #' 
 #' @export
-prodStack <- function(x, y = NULL, 
+prodStack <- function(x,
                       stack = "eco2mix",
                       areas = NULL, 
                       mcYear = "average",
@@ -145,12 +203,46 @@ prodStack <- function(x, y = NULL,
                       legend = TRUE, legendId = sample(1e9, 1),
                       groupId = legendId,
                       legendItemsPerRow = 5,
-                      width = NULL, height = NULL) {
+                      width = NULL, height = NULL, xyCompare = c("union","intersect"),
+                      h5requestFiltering = list(), stepPlot = FALSE, drawPoints = FALSE,
+                      timeSteph5 = "hourly",
+                      mcYearh5 = NULL,
+                      tablesh5 = c("areas", "links"),...) {
   
+  if(!is.null(compare) && !interactive){
+    stop("You can't use compare in no interactive mode")
+  }
+  
+  #Check compare
+  .validCompare(compare,  c("mcYear", "main", "unit", "areas", "legend", "stack", "stepPlot", "drawPoints"))
+
+  xyCompare <- match.arg(xyCompare)
   unit <- match.arg(unit)
   if (is.null(mcYear)) mcYear <- "average"
   
-  params <- .getDataForComp(x, y, compare, compareOpts, function(x) {
+  if(!is.null(compare) && "list" %in% class(x)){
+    if(length(x) == 1) x <- list(x[[1]], x[[1]])
+  }
+  if(!is.null(compare) && ("antaresData" %in% class(x)  | "simOptions" %in% class(x))){
+    x <- list(x, x)
+  }
+  
+  # .testXclassAndInteractive(x, interactive)
+  
+  h5requestFiltering <- .convertH5Filtering(h5requestFiltering = h5requestFiltering, x = x)
+  
+  compareOptions <- .compOpts(x, compare)
+  if(is.null(compare)){
+    if(compareOptions$ncharts > 1){
+      compare <- ""
+    }
+  }
+  
+  init_areas <- areas
+  init_dateRange <- dateRange
+  
+  processFun <- function(x) {
+    
     # Check that input contains area or district data
     if (!is(x, "antaresData")) stop("'x' should be an object of class 'antaresData created with readAntares()'")
     
@@ -165,40 +257,52 @@ prodStack <- function(x, y = NULL,
     if (is.null(x$area)) x$area <- x$district
     timeStep <- attr(x, "timeStep")
     opts <- simOptions(x)
-    if (is.null(areas)) {
-      areas <- unique(x$area)[1]
+    if (is.null(init_areas)) {
+      init_areas <- unique(x$area)[1]
     }
     
     # should mcYear parameter be displayed on the UI?
     displayMcYear <- !attr(x, "synthesis") && length(unique(x$mcYear)) > 1
     
     dataDateRange <- as.Date(.timeIdToDate(range(x$timeId), timeStep, opts))
-    if (length(dateRange) < 2) dateRange <- dataDateRange
+    if (length(init_dateRange) < 2) init_dateRange <- dataDateRange
     
-    plotWithLegend <- function(id, areas, main = "", unit, stack, dateRange, mcYear, legend) {
-      if (length(areas) == 0) return ("Please choose an area")
+    plotWithLegend <- function(id, areas, main = "", unit, stack, dateRange, mcYear, legend, stepPlot, drawPoints) {
+      if (length(areas) == 0) return (combineWidgets("Please choose an area"))
       stackOpts <- .aliasToStackOptions(stack)
-      
       dt <- x[area %in% areas]
       
       if (mcYear == "average") dt <- synthesize(dt)
       else if ("mcYear" %in% names(dt)) {
         mcy <- mcYear
         dt <- dt[mcYear == mcy]
+      }else{
+        .printWarningMcYear()
       }
       
       if (!is.null(dateRange)) {
         dt <- dt[as.Date(.timeIdToDate(dt$timeId, timeStep, opts = opts)) %between% dateRange]
       }
       
-      p <- .plotProdStack(dt, 
-                          stackOpts$variables, 
-                          stackOpts$colors,
-                          stackOpts$lines,
-                          stackOpts$lineColors,
-                          main = main,
-                          unit = unit,
-                          legendId = legendId + id - 1, groupId = groupId)
+      if(nrow(dt) == 0){
+        return (combineWidgets("No data for this selection"))
+      }
+      p <- try(.plotProdStack(dt,
+                              stackOpts$variables,
+                              stackOpts$colors,
+                              stackOpts$lines,
+                              stackOpts$lineColors,
+                              main = main,
+                              unit = unit,
+                              legendId = legendId + id - 1,
+                              groupId = groupId,
+                              dateRange = dateRange,
+                              stepPlot = stepPlot, drawPoints = drawPoints), silent = TRUE)
+      
+      if("try-error" %in% class(p)){
+        return (combineWidgets(paste0("Can't visualize stack '", stack, "'<br>", p[1])))
+      }
+      
       if (legend) {
         l <- prodStackLegend(stack, legendItemsPerRow, legendId = legendId + id - 1)
       } else {
@@ -213,34 +317,208 @@ prodStack <- function(x, y = NULL,
       x = x,
       timeStep = timeStep,
       opts = opts,
-      areas = areas,
+      areas = init_areas,
       displayMcYear = displayMcYear,
       dataDateRange = dataDateRange,
-      dateRange = dateRange
-      
+      dateRange = init_dateRange
     )
-  })
-  
+  }
   if (!interactive) {
-    return(params$x[[1]]$plotWithLegend(1, areas, main, unit, stack, params$x[[1]]$dateRange, mcYear, legend))
+    x <- .cleanH5(x, timeSteph5, mcYearh5, tablesh5, h5requestFiltering)
+    
+    
+    params <- .getDataForComp(x = .giveListFormat(x),
+                              y = NULL, compare = compare,
+                              compareOpts = compareOptions,
+                              processFun = processFun)
+    
+    
+    
+    L_w <- lapply(params$x, function(X){
+      X$plotWithLegend(1, areas, main, unit,
+                       stack, params$x[[1]]$dateRange,
+                       mcYear, legend, stepPlot, drawPoints)
+    })
+    return(combineWidgets(list = L_w))
+    
+  } else {
+    # just init for compare & compareOpts
+    # init_params <- .getDataForComp(x, y, compare, compareOpts, function(x) {})
   }
   
+  
+  table <- NULL
+  
+  ##remove notes
+  mcYearhH5 <- NULL
+  paramsH5 <- NULL
+  sharerequest <- NULL
+  timeStepdataload <- NULL
+  timeSteph5 <- NULL
+  x_in <- NULL
+  x_tranform <- NULL
+  
+  
   manipulateWidget(
-    params$x[[.id]]$plotWithLegend(.id, areas, main, unit, stack, dateRange, mcYear, legend),
-    mcYear = mwSelect(c("average", unique(params$x[[.id]]$x$mcYear)), .display = params$x[[.id]]$displayMcYear),
+    {
+      .tryCloseH5()
+      if(.id <= length(params$x)){
+        widget <- params$x[[max(1,.id)]]$plotWithLegend(.id, areas, main,
+                                                        unit, stack, dateRange,
+                                                        mcYear, legend,
+                                                        stepPlot, drawPoints)
+        controlWidgetSize(widget)
+      } else {
+        combineWidgets("No data for this selection")
+      }
+    },
+    x = mwSharedValue({x}),
+    x_in = mwSharedValue({
+      .giveListFormat(x)
+    }),
+    h5requestFiltering = mwSharedValue({
+      h5requestFiltering
+    }),
+    paramsH5 = mwSharedValue({
+      tmp <- .h5ParamList(X_I = x_in, xyCompare = xyCompare,
+                          h5requestFilter = h5requestFiltering)
+      tmp
+    }),
+    H5request = mwGroup(
+      timeSteph5 = mwSelect(choices = paramsH5$timeStepS, 
+                            value =  paramsH5$timeStepS[1], 
+                            label = "timeStep", 
+                            multiple = FALSE
+      ),
+      tables = mwSelect(choices = paramsH5[["tabl"]][paramsH5[["tabl"]]%in%c("areas", "districts")], 
+                        value = {
+                          if(.initial) {paramsH5[["tabl"]][paramsH5[["tabl"]]%in%c("areas", "districts")][1]}else{NULL}
+                        }, 
+                        label = "table", 
+                        multiple = FALSE
+      ),
+      mcYearhH5 = mwSelect(choices = c(paramsH5[["mcYearS"]]), 
+                         value = {
+                           if(.initial){paramsH5[["mcYearS"]][1]}else{NULL}
+                         }, 
+                         label = "mcYear", 
+                         multiple = TRUE
+      ),
+      .display = {
+        any(unlist(lapply(x_in, .isSimOpts)))
+      }
+    ),
+    
+    sharerequest = mwSharedValue({
+      list(timeSteph5_l = timeSteph5, mcYearh_l = mcYearhH5, tables_l = tables)
+    }),
+    
+
+    
+    x_tranform = mwSharedValue({
+      
+      h5requestFilteringTp <- paramsH5$h5requestFilter
+      if(!is.null(sharerequest))
+      {
+        for(i in 1:length(h5requestFilteringTp))
+        {
+          if(sharerequest$tables == "areas"){
+            h5requestFilteringTp[[i]]$districts = NULL
+          }
+          if(sharerequest$tables == "districts"){
+            h5requestFilteringTp[[i]]$areas = NULL
+          }
+        }
+      }
+
+      sapply(1:length(x_in),function(zz){
+        .loadH5Data(sharerequest, x_in[[zz]], h5requestFilter = h5requestFilteringTp[[zz]])
+      }, simplify = FALSE)
+    }),
+    
+    params = mwSharedValue({
+      .getDataForComp(x_tranform, NULL, compare,
+                      compareOpts = compareOptions, 
+                      processFun = processFun)
+    }),
+    
+    ##End h5
+    mcYear = mwSelect({
+      c("average",  .compareOperation(lapply(params$x, function(vv){
+        unique(vv$x$mcYear)
+      }), xyCompare))
+    }),
+    
     main = mwText(main, label = "title"),
-    dateRange = mwDateRange(params$x[[1]]$dateRange, 
-                            min = params$x[[.id]]$dataDateRange[1], 
-                            max = params$x[[.id]]$dataDateRange[2]),
+    
+    dateRange = mwDateRange(value = {
+      if(.initial){
+        res <- NULL
+        if(!is.null(params)){
+          res <- c(.dateRangeJoin(params = params, xyCompare = xyCompare, "min", tabl = table),
+                   .dateRangeJoin(params = params, xyCompare = xyCompare, "max", tabl = table))
+          ##Lock 7 days for hourly data
+          if(params$x[[1]]$timeStep == "hourly"){
+            if(params$x[[1]]$dateRange[2] - params$x[[1]]$dateRange[1]>7){
+              res[1] <- params$x[[1]]$dateRange[2] - 7
+          }
+          
+          
+        }
+        }
+        
+        
+        
+        res
+      }else{NULL}
+    }, 
+    min = {      
+      if(!is.null(params)){
+        .dateRangeJoin(params = params, xyCompare = xyCompare, "min", tabl = table)
+      }
+    }, 
+    max = {      
+      if(!is.null(params)){
+        .dateRangeJoin(params = params, xyCompare = xyCompare, "max", tabl = table)
+      }
+    }
+    ),
+    
+    
+    
     stack = mwSelect(names(pkgEnv$prodStackAliases), stack),
+    
     unit = mwSelect(c("MWh", "GWh", "TWh"), unit),
-    areas = mwSelect(as.character(unique(params$x[[.id]]$x$area)), areas, multiple = TRUE),
+    
+    areas = mwSelect({
+      as.character(.compareOperation(lapply(params$x, function(vv){
+        unique(vv$x$area)
+      }), xyCompare))
+    },
+    value = {
+      if(.initial){
+        as.character(.compareOperation(lapply(params$x, function(vv){
+          unique(vv$x$area)
+        }), xyCompare))[1]
+      }
+      else{NULL}},
+    multiple = TRUE
+    ),
+    
     legend = mwCheckbox(legend),
-    .compare = params$compare,
-    .compareOpts = params$compareOpts
+    stepPlot = mwCheckbox(stepPlot),
+    drawPoints = mwCheckbox(drawPoints),
+    .compare = {
+      compare
+    },
+    .compareOpts = {
+      compareOptions
+    },
+    ...
   )
 }
 
+
 #' Returns the variables and colors corresponding to an alias
 #' 
 #' @param variables
@@ -299,9 +577,9 @@ prodStack <- function(x, y = NULL,
 #' 
 #' @noRd
 .plotProdStack <- function(x, variables, colors, lines, lineColors, 
-                                 main = NULL, unit = "MWh", legendId = "",
-                                 groupId = legendId,
-                                 width = NULL, height = NULL) {
+                           main = NULL, unit = "MWh", legendId = "",
+                           groupId = legendId,
+                           width = NULL, height = NULL, dateRange = NULL, stepPlot = FALSE, drawPoints = FALSE) {
   
   timeStep <- attr(x, "timeStep")
   
@@ -313,18 +591,17 @@ prodStack <- function(x, y = NULL,
   for (n in names(formulas)) {
     dt[,c(n) := x[, eval(formulas[[n]]) / switch(unit, MWh = 1, GWh = 1e3, TWh = 1e6)]]
   }
-  
   .plotStack(dt, timeStep, simOptions(x), colors, lines, lineColors, legendId,
              groupId,
              main = main, ylab = sprintf("Production (%s)", unit), 
-             width = width, height = height)
+             width = width, height = height, dateRange = dateRange, stepPlot = stepPlot, drawPoints = drawPoints)
 }
 
 #' @rdname tsLegend
 #' @export
 prodStackLegend <- function(stack = "eco2mix", 
-                                  legendItemsPerRow = 5, legendId = "") {
-
+                            legendItemsPerRow = 5, legendId = "") {
+  
   stackOpts <- .aliasToStackOptions(stack)
   
   tsLegend(
@@ -335,3 +612,7 @@ prodStackLegend <- function(stack = "eco2mix",
     legendId = legendId
   )
 }
+
+
+
+
