@@ -3,7 +3,10 @@
 # Copy the test study in a temporary folder
 
 path <- tempdir()
-sourcedir <- system.file("testdata", package = "antaresRead")
+
+sourcedir <- system.file("inst/testdata", package = "antaresRead")
+if(sourcedir == ""){sourcedir <- system.file("testdata", package = "antaresRead")}
+
 
 # Hack: For some unknown reason, this script is executed at some point of
 # the R CMD CHECK before package is correctly installed and tests actually run.
@@ -18,6 +21,7 @@ if (sourcedir != "") {
   
   assign("studyPath", file.path(path, "test_case"), envir = globalenv())
   assign("nweeks", 2, envir = globalenv())
+  assign("pathtemp", path, envir = globalenv())
 }
 
 setSimulationPath(get("studyPath", envir = globalenv()))
